cpufreq
=======

Python module to control the frequency on Linux systems.

Features
--------

-  Get current Frenquency and governor by CPU.
-  Set frequency by CPU.
-  Enable and Disable CPUs.

Prerequisites
-------------

-  Custom CPU power managment enabled on BIOS
-  Power Management Driver installed (acpi for example)
-  Python2 or newer

Site
----

-  https://github.com/VitorRamos/cpufreq

Installation
------------

$ pip3 install cpufreq

Usage
-----

Use the example file script: cpufreq\_example.py
